From 84e76958971ddecbf21e99ae778543a976eefee6 Mon Sep 17 00:00:00 2001
From: Pradip Thapa <pingpradip456@gmail.com>
Date: Fri, 22 Nov 2024 10:03:15 +0545
Subject: [PATCH] fix: update take-off point from 200m to 350m (#348)

---
 src/backend/app/waypoints/waypoint_routes.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/backend/app/waypoints/waypoint_routes.py b/src/backend/app/waypoints/waypoint_routes.py
index c4317103..fab6f6ba 100644
--- a/src/backend/app/waypoints/waypoint_routes.py
+++ b/src/backend/app/waypoints/waypoint_routes.py
@@ -66,11 +66,11 @@ async def get_task_waypoint(
     if take_off_point:
         take_off_point = [take_off_point.longitude, take_off_point.latitude]
 
-        # Validate that the take-off point is within a 200m buffer of the task boundary
-        if not check_point_within_buffer(take_off_point, task_geojson, 200):
+        # Validate that the take-off point is within a 350 buffer of the task boundary
+        if not check_point_within_buffer(take_off_point, task_geojson, 350):
             raise HTTPException(
                 status_code=400,
-                detail="Take off point should be within 200m of the boundary",
+                detail="Take off point should be within 350m of the boundary",
             )
 
         # Update take_off_point in tasks table